@@ -6,7 +6,7 @@ from collections import defaultdict
 from dataclasses import dataclass
 from io import IOBase
 from pathlib import Path
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Dict, Iterable, List, MutableMapping, Optional, Tuple, Union
 
 import click
 import robot.running.model as running_model
@@ -224,12 +224,13 @@ def get_rel_source(source: Optional[str]) -> Optional[str]:
 class Collector(SuiteVisitor):
     def __init__(self) -> None:
         super().__init__()
+        absolute_path = Path.cwd()
         self.all: TestItem = TestItem(
             type="workspace",
-            id=str(Path.cwd().resolve()),
-            name=Path.cwd().name,
-            longname=Path.cwd().name,
-            uri=str(Uri.from_path(Path.cwd())),
+            id=str(absolute_path),
+            name=absolute_path.name,
+            longname=absolute_path.name,
+            uri=str(Uri.from_path(absolute_path)),
             needs_parse_include=get_robot_version() >= (6, 1),
         )
         self._current = self.all
@@ -238,7 +239,7 @@ class Collector(SuiteVisitor):
         self.tags: Dict[str, List[TestItem]] = defaultdict(list)
         self.normalized_tags: Dict[str, List[TestItem]] = defaultdict(list)
         self.statistics = Statistics()
-        self._collected = [NormalizedDict(ignore="_")]
+        self._collected: List[MutableMapping[str, Any]] = [NormalizedDict(ignore="_")]
 
     def visit_suite(self, suite: TestSuite) -> None:
         if suite.name in self._collected[-1] and suite.parent.source:
@@ -255,12 +256,13 @@ class Collector(SuiteVisitor):
         self._collected[-1][suite.name] = True
         self._collected.append(NormalizedDict(ignore="_"))
         try:
+            absolute_path = Path(suite.source).resolve() if suite.source else None
             item = TestItem(
                 type="suite",
-                id=f"{Path(suite.source).resolve() if suite.source is not None else ''};{suite.longname}",
+                id=f"{absolute_path or ''};{suite.longname}",
                 name=suite.name,
                 longname=suite.longname,
-                uri=str(Uri.from_path(Path(suite.source).resolve())) if suite.source else None,
+                uri=str(Uri.from_path(absolute_path)) if absolute_path else None,
                 source=str(suite.source),
                 rel_source=get_rel_source(suite.source),
                 range=Range(
@@ -307,19 +309,20 @@ class Collector(SuiteVisitor):
         if self._current.children is None:
             self._current.children = []
         try:
+            absolute_path = Path(test.source).resolve() if test.source is not None else None
             item = TestItem(
                 type="test",
-                id=f"{Path(test.source).resolve() if test.source is not None else ''};{test.longname};{test.lineno}",
+                id=f"{absolute_path or ''};{test.longname};{test.lineno}",
                 name=test.name,
                 longname=test.longname,
-                uri=str(Uri.from_path(Path(test.source).resolve())) if test.source else None,
+                uri=str(Uri.from_path(absolute_path)) if absolute_path else None,
                 source=str(test.source),
                 rel_source=get_rel_source(test.source),
                 range=Range(
                     start=Position(line=test.lineno - 1, character=0),
                     end=Position(line=test.lineno - 1, character=0),
                 ),
-                tags=list(test.tags) if test.tags else None,
+                tags=list(set(normalize(str(t), ignore="_") for t in test.tags)) if test.tags else None,
             )
         except ValueError as e:
             raise ValueError(f"Error while parsing suite {test.source}: {e}") from e
@@ -335,6 +338,13 @@ class Collector(SuiteVisitor):
 
 
 @click.group(invoke_without_command=False)
+@click.option(
+    "--diagnostics / --no-diagnostics",
+    "show_diagnostics",
+    default=True,
+    show_default=True,
+    help="Display `robot` parsing errors and warning that occur during discovering.",
+)
 @click.option(
     "--read-from-stdin",
     is_flag=True,
@@ -342,7 +352,7 @@ class Collector(SuiteVisitor):
     hidden=show_hidden_arguments(),
 )
 @pass_application
-def discover(app: Application, read_from_stdin: bool) -> None:
+def discover(app: Application, show_diagnostics: bool, read_from_stdin: bool) -> None:
     """\
     Commands to discover informations about the current project.
 
@@ -353,6 +363,7 @@ def discover(app: Application, read_from_stdin: bool) -> None:
     robotcode --profile regression discover tests
     ```
     """
+    app.show_diagnostics = show_diagnostics or app.config.log_enabled
     if read_from_stdin:
         global _stdin_data
         _stdin_data = from_json(sys.stdin.buffer.read(), Dict[str, str], strict=True)
@@ -419,7 +430,6 @@ def build_diagnostics(messages: List[Message]) -> Dict[str, List[Diagnostic]]:
 
 def handle_options(
     app: Application,
-    diagnostics: bool,
     by_longname: Tuple[str, ...],
     exclude_by_longname: Tuple[str, ...],
     robot_options_and_args: Tuple[str, ...],
@@ -444,7 +454,7 @@ def handle_options(
 
         settings = RobotSettings(options)
 
-        if diagnostics:
+        if app.show_diagnostics:
             LOGGER.register_console_logger(**settings.console_output_config)
         else:
             LOGGER.unregister_console_logger()
@@ -502,17 +512,6 @@ def handle_options(
     raise UnknownError("Unexpected error happened.")
 
 
-DIAGOSTICS_OPTIONS = {
-    click.option(
-        "--diagnostics / --no-diagnostics",
-        "show_diagnostics",
-        default=True,
-        show_default=True,
-        help="Display `robot` parsing errors and warning that occur during discovering.",
-    )
-}
-
-
 @discover.command(
     context_settings={
         "allow_extra_args": True,
@@ -521,12 +520,10 @@ DIAGOSTICS_OPTIONS = {
     add_help_option=True,
     epilog='Use "-- --help" to see `robot` help.',
 )
-@add_options(*DIAGOSTICS_OPTIONS)
 @add_options(*ROBOT_OPTIONS)
 @pass_application
 def all(
     app: Application,
-    show_diagnostics: bool,
     by_longname: Tuple[str, ...],
     exclude_by_longname: Tuple[str, ...],
     robot_options_and_args: Tuple[str, ...],
@@ -546,9 +543,7 @@ def all(
     ```
     """
 
-    suite, collector, diagnostics = handle_options(
-        app, show_diagnostics, by_longname, exclude_by_longname, robot_options_and_args
-    )
+    suite, collector, diagnostics = handle_options(app, by_longname, exclude_by_longname, robot_options_and_args)
 
     if collector.all.children:
         if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
@@ -611,12 +606,10 @@ def all(
     show_default=True,
     help="Show full paths instead of releative.",
 )
-@add_options(*DIAGOSTICS_OPTIONS)
 @add_options(*ROBOT_OPTIONS)
 @pass_application
 def tests(
     app: Application,
-    show_diagnostics: bool,
     full_paths: bool,
     show_tags: bool,
     by_longname: Tuple[str, ...],
@@ -638,9 +631,7 @@ def tests(
     ```
     """
 
-    suite, collector, diagnostics = handle_options(
-        app, show_diagnostics, by_longname, exclude_by_longname, robot_options_and_args
-    )
+    suite, collector, diagnostics = handle_options(app, by_longname, exclude_by_longname, robot_options_and_args)
 
     if collector.all.children:
         if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
@@ -654,7 +645,7 @@ def tests(
                     )
                     if show_tags and item.tags:
                         yield click.style("    Tags:", bold=True)
-                        yield f" {', '. join(normalize(str(tag), ignore='_') for tag in item.tags)}{os.linesep}"
+                        yield f" {', '. join(normalize(str(tag), ignore='_') for tag in sorted(item.tags))}{os.linesep}"
 
             if collector.tests:
                 app.echo_via_pager(print(collector.tests))
@@ -671,12 +662,10 @@ def tests(
     add_help_option=True,
     epilog='Use "-- --help" to see `robot` help.',
 )
-@add_options(*DIAGOSTICS_OPTIONS)
 @add_options(*ROBOT_OPTIONS)
 @pass_application
 def suites(
     app: Application,
-    show_diagnostics: bool,
     by_longname: Tuple[str, ...],
     exclude_by_longname: Tuple[str, ...],
     robot_options_and_args: Tuple[str, ...],
@@ -696,9 +685,7 @@ def suites(
     ```
     """
 
-    suite, collector, diagnostics = handle_options(
-        app, show_diagnostics, by_longname, exclude_by_longname, robot_options_and_args
-    )
+    suite, collector, diagnostics = handle_options(app, by_longname, exclude_by_longname, robot_options_and_args)
 
     if collector.all.children:
         if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
@@ -748,12 +735,10 @@ class TagsResult:
     show_default=True,
     help="Show full paths instead of releative.",
 )
-@add_options(*DIAGOSTICS_OPTIONS)
 @add_options(*ROBOT_OPTIONS)
 @pass_application
 def tags(
     app: Application,
-    show_diagnostics: bool,
     normalized: bool,
     show_tests: bool,
     full_paths: bool,
@@ -777,15 +762,13 @@ def tags(
     ```
     """
 
-    _suite, collector, _diagnostics = handle_options(
-        app, show_diagnostics, by_longname, exclude_by_longname, robot_options_and_args
-    )
+    _suite, collector, _diagnostics = handle_options(app, by_longname, exclude_by_longname, robot_options_and_args)
 
     if collector.all.children:
         if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
 
             def print(tags: Dict[str, List[TestItem]]) -> Iterable[str]:
-                for tag, items in tags.items():
+                for tag, items in sorted(tags.items()):
                     yield click.style(f"{tag}{os.linesep}", bold=show_tests, fg="green" if show_tests else None)
                     if show_tests:
                         for t in items:
